@@ -2103,6 +2103,7 @@ mcd_async_request_handle_callback(DBusGProxy *proxy, GArray *handles,
 		 mcd_channel_get_handle_type (existing_channel),
 		 mcd_channel_get_channel_type (existing_channel));
 	if (chan_handle == mcd_channel_get_handle (existing_channel) &&
+	    chan_handle_type == mcd_channel_get_handle_type (existing_channel) &&
 	    strcmp(chan_type,
 		   mcd_channel_get_channel_type (existing_channel)) == 0)
 	{
@@ -2173,7 +2174,7 @@ mcd_connection_request_channel (McdConnection *connection,
     /* We do not add the channel in connection until tp_channel is created */
     g_object_set_data (G_OBJECT (channel), "temporary_connection", connection);
     
-    if (req->channel_handle != 0 || req->channel_type == 0)
+    if (req->channel_handle != 0 || req->channel_handle_type == 0)
     {
 	DBusGProxyCall *call;
 	/* the channel stays in priv->pending_channels until a telepathy
